#
# spec file for package perl-ldap
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name perl-ldap
Name:           perl-ldap
Version:        0.68
Release:        2.10
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Perl::ldap Perl module
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MA/MARSCHAP/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Convert::ASN1) >= 0.2
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.42
BuildRequires:  perl(Text::Soundex)
Requires:       perl(Convert::ASN1) >= 0.2
Recommends:     perl(Authen::SASL) >= 2.00
Recommends:     perl(IO::Socket::INET6)
Recommends:     perl(IO::Socket::SSL) >= 1.26
Recommends:     perl(URI::ldap) >= 1.10
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  perl(Digest::MD5)
BuildRequires:  perl(IO::Socket::INET6)
BuildRequires:  perl(IO::Socket::IP)
BuildRequires:  perl(JSON)
BuildRequires:  perl(MIME::Base64)
BuildRequires:  perl(URI)
# MANUAL END

%description
perl::ldap Perl module

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644
# MANUAL BEGIN
find contrib -type f | xargs -n 1 sed -i "s@%{_prefix}/local/bin/perl@%{_bindir}/perl@"
# MANUAL END

%build
PERL_USE_UNSAFE_INC=1 perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CREDITS README TODO

%changelog
* Mon Sep 27 2021 Dirk Stoecker <opensuse@dstoecker.de>
- fix build with perl 5.34.0
* Wed Jun  9 2021 Pedro Monreal <pmonreal@suse.com>
- Add cpanspec.yml as source file
- Review the package dependencies
* Fri Jun  4 2021 Pedro Monreal <pmonreal@suse.com>
- Update to 0.68
  * 0.68 -- Sun Jan  3 17:58:18 CET 2021
  - Enhancements:
  * Control/NoOp.pm: new
  * Control/Subentries.pm: new
  * Constant.pm: add tags to allow exporting groups of constants
  * Constant.pm: add Active Directory Control & Extension OIDs
  * Constant.pm: add references to perl-ldap's modules
  - Bug Fixes:
  * META.json: update author & bugtracker
  * Control/*.pm: typo & grammar fixes
  * Control/Relax.pm: slight rephrasing
  * FAQ.pod: fix spelling/grammar error
  * Changes: fix typo
  * 0.67 -- Sat Dec 26 14:50:55 CEST 2020
  - Enhancements:
  * Makefile.PL: update author & bugtracker
  * LDIF.pm: support controls when reading
  * Control/TreeDelete.pm: new
  * Entry.pm: new option 'nooptions' for get_value()
  * various typo fixes
  - Bug Fixes:
  * LDAP.pm: do not persist the default sslserver
  * LDAP.pm: correct parameter to restrict IP family with IO::Socket::IP
  * data/regenerate_cert.sh: fix shebang
- Add missing dependencies for building and testing
* Mon Nov 11 2019 Arjen de Korte <suse+build@de-korte.org>
- Change architecture to 'noarch'
* Mon Jun 17 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- update to 0.66
  Enhancements
  * Entry.pm: accept more options in ldif()
  * inc/: refresh install tools
  * contrib/ldifsort: new option -h
  * documentation extensions
  * typo fixes
  Bug Fixes
  * contrib/schema2ad: fix syntax calculation
  * Refresh.pm: fix get_ttl() method
  * DSML: fix detection of auxiliary object classes
- Dropped patch fixed upstream perl526.patch
- Updated URL to MetaCPAN
- Updated spec file with spec-cleaner
* Fri Sep 29 2017 coolo@suse.com
- add perl526.patch to build with perl 5.26
- remove ssl subpackage without files
* Fri Sep 29 2017 coolo@suse.com
- update to 0.65
  Enhancements:
  * t/74matchedvalues.t: more tests
  * {ASN,Extension}.pm: update ExtendedResponse to RFC 4511
  * Constant.pm: add LDAP_NOTICE_OF_DISCONNECTION
  * Control/DontUseCopy.pm: new
  * Control/ProxyAuth.pm: make sure criticality does not get changed
  * Control/Relax.pm: make sure value & criticality do not get changed
  * Control/ManageDsaIT.pm: make sure value never gets set
  Bug Fixes
  * LDAP.pm: do not set default sslversion for start_tls() & LDAPS
    Instead of second-guessing a default sslversion for start_tls() and LDAPS,
    rely on the - known to be sane - default value used by IO::Socket::SSL.
  * RT#100151: LDAP.pm: localize $SIG{__DIE__} in IPv6 support check
    Thanks to Troy Loveday <troyl@ti.com> for the detailed bug report and patch.
  * FAQ.pod: fix error in search() example
  * RFC.pod: typo fix
* Fri Feb 13 2015 aj@ajaissle.de
- update to 0.64
  0.64 -- Thu Jun 19 17:48:08 CEST 2014
  Bug Fixes:
  * LDAP.pm: set SSL_cipher_list correctly
  * RT#96203: LDAP.pm: use correct length for syswrite
  * LDIF.pm: fix next outside loop in _write_one_entry
  * Entry.pod: fix typo
  0.63 -- Sun Jun  1 12:42:59 CEST 2014
  Enhancements:
  * Entry.pm: accept options for update() in the LDIF case
  * LDIF.pm:
  - implement writing controls
  - refactor _write_entry
  - check for decoding errors in LWP-based URLs
  Bug Fixes:
  * RT#95001: Do not set SSL_ciphers to ALL by default
  * Entry.pm: delete(): return $self if called w/o args
  0.62 -- Sun Apr  6 11:25:05 CEST 2014
  Enhancements:
  Util.pm: remove superfluous space from POD
  FAQ.pm: update perl-ldap & Perl version numbers
  Bug Fixes:
  RT#94357: t/08time.t: skip tests on too old Perl versions
  RT#94341: FAQ.pm: fix incorrect instruction
  jpegDisplay.pl: overhaul to make it work again
  0.61 -- Sat Mar 29 17:21:45 CET 2014
  Enhancements:
  * {LDAP,LDIF}.pod: update documentation of raw => REGEX
  * support LWP-supproted URLs when reading LDIFs (incl. tests)
  * add test for Net::LDAP::Util's time functions
  * tests: set default OpenLDAP DB type to mdb
  Bug Fixes:
  * RT#94047: Control.pm: add missing word in POD
  * RT#93945: Util.pm: make sure $dec is defined
  * LDIF.pm: when reading LDIFs, allow control values to be absent
  * Control/ProxyAuth.pm: fix initialization using value => ...
  * Util.pm: fix corner cases in time conversion functions
  0.60 -- Sat Mar  8 14:00:02 CET 2014
  Enhancements:
  * IO::Socket::IP support
  - if installed in version 0.20 or higher, prefer it over IO::Socket::INET*
  - use IO::Socket::INET* as fallback if it isn't installed
  - this solves RT#93122, which IMHO is not really a bug of perl-ldap
  * remove trailing whitespace in contrib/*
  0.59 -- Tue Mar  4 16:21:15 CET 2014
  Bug Fixes:
  * Handle SASL security layers correctly on rebind
  Thanks Ben Morrow <ben@morrow.me.uk>
  * Control/Paged.pm: fix typo in POD sample code
  Enhancements:
  * t/60cancel.t: add explanation about potential cause of failure
  * LDAP.pm: accessor method sasl for Authen::SASL object
  * LDAP.pm: adapt socket() to support SASL layers
  * Message.pod: consolidate dcwocumentation of control()
  * Control.pm: documentation update
  * LDAP.pod: add note about IO::Socket::IP and Timeout
  * LDIF.pm: overhaul
  - set error when write fails
  - simplify _read_entry
  - simplify _write_entry
  - coding style harmonization
  - error checks when reading changetype: delete
  - make _error() return undef/empty list, adapt callers
  - refactor handling DNs when reading
  - new method _read_attribute_value()
  0.58 -- Mon Dec 23 17:35:53 CET 2013
  Bug Fixes:
  * RT#91210: Paged.pm: fix example code
  * RT#90459: LDAP.pm: make LDAPS work after LDAP+start_tls
  * RT#91177: AD.pm: fix change_ADpassword()
  * RT#88792: Constant.pm: add LDAP_CONTROL_SORTRESPONSE
  Enhancements:
  * Filter.pod: remove misleading text
  * typo fixes
  * RT#91156: add META.json
  * DSML.pm, Protocol/ldap.pm: use MIME::Base64::decode()
  * make MIME::Base64 mandatory
  * README: update optional modules, slight reorganization
  * Entry.pod: update documentation of N:L:E->update
  * Makefile.PL: require Text::Soundex for tests
  0.57 -- Sun Jul 21 18:35:12 CEST 2013
  COMPATIBILITY WARNING:
  The bug fix "LDAP.pm: new parameter bind(sasl_host => SASLHOST)"
  is an incompatible change that may break some corner-case configurations
  * that use SASL for authentication and
  * where the SASL host name differs from the host name connecting to.
  The incompatible change was necessary as it was not possible to fix
  the issue which was introduced in perl-ldap 0.37 in a compatible way.
  See Net::LDAP's manual page for the details on "sasl_host".
  Bug Fixes:
  * LDAP.pm: new parameter bind(sasl_host => SASLHOST)
  * Entry.pm: ignore options when update()ing LDIF
  * Entry.pm: let update() fail correctly on illegal target
  * RT#86053: FAQ.pod: fix spelling error
  * *.{pm,pod}: lots of more grammar & spelling fixes / harmonizations
  Enhancements:
  * LDAP.pm: use data_ready() in process()
  * Util.pm: simplify return on error
  * Constant.pm: add constant LDAP_CONTROL_NOOP
  * Schema.pm: call isa() as recommented in UNIVERSAL.pm
  0.56 -- Sat Jun 8 13:14:47 CEST 2013
  Bug Fixes:
  * RT#85941: LDAP.pm: new method data_ready()
  * RT#84886: Control/Relax.pm: fix typo in documentation
  Enhancements:
  * FAQ.pod: add more directory servers
  * t/07filtermatch.t: skip some tests unless Text::Soundex is installed
  * t/74matchedvalues.t: new, tests for MatchedValues control
  * t/73assert.t: new, tests for Assertion control
  * LDIF.pm: overhaul
  - flexibilize mode handling, accept PerlIO layers
  - get rid of dependency on Symbol & SelectSaver
  - convert _write_... to object methods
  - use indirect file handles for URLs
  * LWP/Protocol/ldap.pm: use regex as 1st arg to split()
  0.55 -- Tue Apr 23 11:18:15 CEST 2013
  Bug Fixes:
  RT#84410: PersistentSearch.pm: use $message->pop_entry() in example
  RT#84774: Constant.pm: unbreak Novell eDirectory constants
  Enhancements:
  Control/ManageDsaIT.pm: update documentation & simplify a bit
  Control/Relax.pm: new
  Constant.pm: add LDAP_CONTROL_RELAX
  LDAP.pod: omit space from filter in synopsis
  FAQ.pod: don't talk of "2 lines" when there's only one
  Extra/eDirectory.pm: fix typo, space police
  0.54 -- Fri Mar 29 12:07:40 CET 2013
  Bug Fixes:
  * RT#73202: LDIF.pm: Base64-encode values ending in spaces
  * RT#83815: fix typo/bug in example for root_dse
  Enhancements:
  * FAQ.pod: mention Dancer::Plugin::LDAP, update example
  * Extra/eDirectory.pm: new; extensions for eDirectory
  * Constant.pm: add constants for Novell eDirectory
  * LDIF.pm: clean up handling of mode parameter
  * LDIF.pm: partially support controls when reading
  * Util.pm: add time conversion functions
  * Makefile.PL: update recommends, add comments on core modules
  * FAQ.pod: update info on required/optional modules
  * LDAP.pod,FAQ.pod: harmonize documentation of scope values
  0.53 -- Sat Jan 26 18:23:35 CET 2013
  Bug Fixes:
  * various clarification & fixes in documentation
  * t/7{1pre,2post}read.t: don't use deprecated methods
  Enhancements:
  * Filter.pm: new method negate()
  * Util.pm: new function ldap_url_parse()
  * RT#77716: LDAP.pm: new option keepalive for new()
  * LDAP.pm: convert scheme to lowercase in new()
  * FAQ.pod: how to search all members of a large AD group
  * FAQ.pod: how to do nested group searches in AD
  0.52 -- Tue Jan 1 13:54:22 CET 2013
  Bug Fixes:
  * fix PreRead & PostRead controls
  * AD.pm: fix typo in documentation
  Enhancements:
  * add tests for PreRead & PostRead controls
  * FAQ.pm: example for certificateExactMatch
  * coding style overhaul:
  * use single-quoted strings where possible
  * 2 SPACEs before postfix if,unless,or,and
  * SPACE after comma
  * SPACE between if,elsif,unless,while,for and (
  * make private lexical variables more private
  * unquote identifiers before =>
  * unquote identifiers used as hash keys
  0.51 -- Sat Dec 1 14:37:35 CET 2012
  Bug Fixes:
  * RT#81380: in Filter.pm unescape hexpairs and ( ) \ * only
  * tests: compare files in "text mode"
  * Makefile.PL: mention all requirements for tests
  Enhancements:
  * Schema.pod: document attribute_syntax()
  * contrib/schema2ad.pl: new, convert schema file to something AD can digest
  0.50 -- Sat Nov 24 13:03:45 CET 2012
  Bug Fixes:
  * t/07filtermatch.t: use core module Text::Soundex instead of String::Approx
  * Message.pm: fix regression w.r.t. Net::LDAP::Message::Dummy
  Enhancements:
  * Makefile.PL: make dependencies reflect reality better
  * LDAP.pm: avoid warning in new() that might have occurred in corner cases
  0.50_01 -- Sat Nov 17 18:05:15 CET 2012
  Bug Fixes:
  * RT#80482 fix display of =item inet6 in LDAP.pod
  * RT#66753: new key & cert for SSL server tests
  * RT#79763 Net::LDAP::Util's $VERSION increased
  * t/06constant.t: numbering glitch in t/06constant.t
  * FilterMatch.pm: fix mapping of greaterOrEqual
  * FAQ.pod: small fixes
  Enhancements:
  * add constant LDAP_PROXY_AUTHZ_FAILURE
  * FilterMatch.pm: complete overhaul
  - update matching rules known in OpenLDAP
  - support matching rules for extensibleMatch
  - avoid warning if no matching rule is found
  - add specific implementations for a lot of rules
  * global overhaul towards Perl 5.8 features
  - declare @ISA and $VERSION as package-local
  - replace 'use vars' by 'our'.
  * Makefile.PL: overhaul
  * tests: cleanup & extensions
  - convert to Test::More
  - t/common.pl: allow client() to take options for Net::LDAP
  - t/common.pl: get rid of local compare function
  - t/03schema.t: overhaul, update data/schema.in
  - t/07filtermatch.t: new, tests for Net::LDAP::FilterMatch
  - t/40connect.t: new, test for IPv4 / IPv6 connections
  - reorganize servers tests: rename t/5X*.t -> t/4(X+1)*.t
  - t/47ipc.t: add TLS tests
  - t/60cancel.t: new, tests for Net::LDAP::Extension::Cancel
  - t/70sortctrl.t: make it a server test & add multi-attribute testcase
  0.49 -- Sat Oct 5 10:00:30 CEST 2012
  Bug Fixes:
  * RT#79763 extend ldap_explode_dn() for RFC 4514
  * RT#77291 canonicalize host name with ldapi://
  * LDAP.pm: don't try to set errors on undefined objects
  Extensions:
  * Net/LDAP/Extra/AD.pm:  convenience functions for AD
  * various documentation updates
  0.48 -- Thu Sep 20 10:55:20 CEST 2012
  Bug Fixes:
  * Util.pm: fix bug in escape_dn_value()
  * t/55ssl.t: fix typos in output text
  * LDIF.pm: with encode => 'canonical', do mbcescape DNs
  * the usual typo fixes in docs
  Enhancements:
  * ASN.pm: adapt to RFC 4511
  * Extension/{SetPassword,Refresh}.pm: polish ASN.1 definition
  * LWP/Protocol/ldap.pm: respond with requested MIME type
  * LWP/Protocol/ldap.pm: document 'x-format' URI extension
  * LWP/Protocol/ldap.pm: add DSMLv1 as output format
  * test routines updated to work with recent OpenLDAP
  * removed trailing spaces
  * support OpenLDAP extension: scope => "children"
  0.47 -- Sun Sep 16 12:00:30 CEST 2012
  Bug Fixes
  * contrib/ldifdiff.pl: fix POD
  * Intermediate/SyncInfo.pm: fix newcookie() method
  * LWP/Protocol/ldap.pm: complete overhaul
  Enhancements
  * more feature constants in Net/LDAP/Constant.pm
  * new features & documentation for LWP/Protocol/ldap.pm
  * LWP/Protocol/ldapi.pm: support ldapi:// URIs with LWP
  * contrib/LWPsearch.pl: demo program for LWP::Protocol::ldap*
  * update link list in the FAQ
  * update references to RFCs
  0.46 -- Wed Sep 5 18:09:00 CEST 2012
  Bug Fixes
  * LDAP.pm: unbreak - make done a real sub
  * Message.pm: fix typo, i.e. add forgotten ';'
  Enhancements:
  * FAQ.pod: update URLs a bit more
  0.45 -- Wed Sep 5 11:20:46 CEST 2012
  Bug Fixes
  * RT#72108 fix non-blocking IO with SSL
  * RT#74572 fix $entry->update($ldif)
  * RT#74759 fix POD spelling/grammar errors
  * RT#77180 use "sslv23" instead of "sslv2/3" for sslversion
  * work around a warning in Authen::SASL::Perl <= 2.1.5
  * various typo fixes in documentation
  Enhancements
  * RT#77458 re-work IPv6 support
  * Don't accumulate intermediate messages passed to a callback.
  * slightly extend Net::LDAP::Entry->update() and document it
  * convenience alias done() for Net::LDAP->unbind()
  * various updates to the FAQ
* Mon Sep  9 2013 coolo@suse.com
- switch to new macros to fix build
* Mon Jan 30 2012 vcizek@suse.com
- update to 0.44
  Bug Fixes
  * un-break certificate verification
  * fixes for the ProxyAuthorization control
  * fix typos & spelling errors in POD
  Enhancements
  * MANIFEST.SKIP: sync with Perl 5.14.2's ExtUtils version
  * Makefile.PL: update resource info on repository
  * new extended operation Net::LDAP::Extension::Cancel
  * new control Net::LDAP::Control::MatchedValues
  * new control Net::LDAP::Control::Assertion
  * update reference documents in POD
  * extend documentation for Pre-Read & Post-Read controls
  * add error string for LDAP_VLV_ERROR
  * add result codes for VLV and cancel
  * add constant for DontUseCopy control
  * add constant for PermissiveModify control
* Mon Sep  5 2011 vcizek@suse.com
- update to 0.43
  * Fix copy & paste errors in Net::LDAP::Message
  0.42 -- Sat Sep 3 07:46:06 CDT 2011
  * Check whether LDAP socket object has a peerhost() method defined
    before calling it. This fixes SASL authentication over
    UNIX domain (ldapi://) sockets. [Chris Mikkelson]
  0.41 -- Sat Sep 3 07:37:31 CDT 2011
  * use of non-localised $_ in Net::LDAP::Constant causes prolems
    in lemonldap-ng [Damyan Ivanov]
  * Added cn,o,ou to the default set of case-insensitive attributes
  * Entry.pod: fix typos [Peter Marschall]
  * extend Net::LDAP::Entry->update() to take LDIF objects
  * Specify that we want to use the 'ldap' scheme to verify certificates
- licence correction
* Fri Jan  7 2011 vcizek@novell.com
- update to 0.4001
  * Update Module::Install and generate META.yml
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Mon Apr 19 2010 dmueller@suse.de
- update to 0.4001:
  * Update Module::Install and generate META.yml
* Wed Mar 24 2010 rbos@opensuse.org
- update to 0.40
  * Avoid 'cookie parsing error' on OpenLDAP 2.3 [Mathieu Parent]
  * Added e-syncRefreshRequired constant [Mathieu Parent]
  * Minor typo fix in documentation [Quanah Gibson-Mount]
  * Update CREDITS for Mathieu Parent
  * Remove runtime dependency on DATA handle for constants
  * Clarify documentation for gen_password
  * Allow caller to pass Authen::SASL client_new object
  * fix typo [Peter Marschall]
  * use current IO::Socket::SSL's method start_SSL instead of deprecated function socketToSSL; raise required IO::Socket:SSL version appropriately [Peter Marschall]
  * FilterMatch.pm: fix regex treatment in _{cis,exact}_substrings(). [Peter Marschall]
  * FilterMatch.pm: correct # of args in function declarations/definitions [Peter Marschall]
  * Don't duplicate documentation [Mathieu Parent]
  * Added numcmp option to compare attributes numerically. [Kartik Subbarao]
  * Avoid infinite loop when authenticating with EXTERNAL mechanism
  * Add Net::LDAP::Extension::Refresh as described in RFC2589 [Etienne Bagnoud]
  * RT#40068 Fix tests to work with 2.4.11
  * Add ldif method to Net::LDAP::Entry
  * RT#46111 Make LWP::Protocol::ldap return ldif when requested
  * RT#51165 Compact multiple consecutive spaces in Net::LDAP::Util::canonical_dn
  * RT#46125 Add LWP::Protocol::ldaps to support ldaps: urls
  * RT#44110 Fix Net::LDAP::LDIF->current_lines
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Tue Jul 28 2009 rbos@opensuse.org
- Added patch SyncRequestCookie.patch to avoid 'cookie parsing error'
  in combination with openldap-2.3
- Added chmod -x to prevent a rpmlint warning
* Mon Feb 23 2009 anicka@suse.cz
- update to 0.39
  * Several fixes to the handling of IntermediateMessage and LDAP
  Content synchronisation
  * Fix dsmt test to not fail on win32
  * Fix Net::LDAP::Util to not cause Undefined subroutine
  &Net::LDAP::Util::ldap_error_desc
  * Fix bug in Net::LDAP::Extension using wrong field for resultCode
  * Fix Net::LDAP::Control::PasswordPolicy decoding bug.
  * Net::LDAP::Extension::SetPassword now supports controls
* Wed Sep 10 2008 anicka@suse.cz
- update to 0.37
  * Add Modify Increment (RFC 4525) support
  * Add Content Synchronization (RFC 4453) support
  * Added controls for PreRead & PostRead
  * Added vendorName/vendorVersion (RFC 3045) to root_dse()
  * add option to support IPv6
  * Allow Entry->deleted to be called with a single value is well
  as array ref
  * Added Net::LDAP::Control::PasswordPolicy to support draft RFC
  * bugfixes
* Tue Jul 15 2008 jw@suse.de
- perl-ldap does not conform to our naming conventions for perl packages.
  Added a Provides: perl-Net-LDAP to make user's life easier.
  (Using version numbers, to allow future package rename)
* Mon Mar 10 2008 anicka@suse.cz
- update to 0.34
  * Improve dealing with mixed case attributes in Net::LDAP::Entry
  * Documentation fixes & updates
  * Don't let Net::LDAP->bind() die on SASL errors
  * Fix case-folding in Net::LDAP::Util::ldap_explode_dn()
  * Saner default for ldapi socket
  * Update test suite to work with recent OpenLDAP versions
  * The usual bunch of typo fixes
  * Fix escaping on non-ascii characters in Net::LDAP::Filter
  * Flexible handling of line ends in Net::LDAP::LDIF when reading
  * Improve writing speed in Net::LDAP::LDIF
  * Net::LDAP accessor methods for scheme, host, port, URI connected to
  * New checkcrl option to Net::LDAP->new() to do CRL checking
  * New package Net::LDAP::Filtermatch for client side filtering
  * More ASN1 messages handled in Net::LDAP:ASN: IntermediateResponse
  * Option 'raw' to return Perl UTF-8 strings from queries (requires Perl 5.8)
  * Support  Active Directory's extendedAttributeInfo schema information
  * Method to find matchingrule for an attribute in Net::LDAP:Schema
  * Updated build dependecies: GSSAPI support, ..
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jul 27 2005 mt@suse,de
- update to 0.33
- fixed file list to be more exact
* Sun Jun 20 2004 ro@suse.de
- fix find command in specfile
* Sat Feb 28 2004 ro@suse.de
- fix requires for /usr/local
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Thu Jul 24 2003 mjancar@suse.cz
- update to 0.29
* Fri Jul 18 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Mon Jun 16 2003 mjancar@suse.cz
- update to 0.28
- fix filelist
* Mon May 19 2003 ro@suse.de
- remove perllocal.pod
* Sat Dec 28 2002 prehak@suse.cz
- updated to version 0.26
- added perl-Authen-SASL to neededforbuild
* Wed Sep 11 2002 prehak@suse.cz
- used %%{version} in subpackage's Requires
* Mon Jul 29 2002 mls@suse.de
- Fixed neededforbuild for perl-5.8.0
* Thu Jul 11 2002 prehak@suse.cz
- update to version 0.251
- added more documentation and contrib
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Thu Jan 17 2002 rvasice@suse.cz
- update to version 0.25
* Tue Aug 14 2001 rvasice@suse.cz
- update to version 0.24
* Mon Mar 26 2001 cihlar@suse.cz
- added make test
- fixed neededforbuild
* Tue Nov 14 2000 cihlar@suse.cz
- renamed perl_ldp -> perl-ldap
    p_ldaps  -> perl-ldap-ssl
- update to version 0.22
- bzipped sources
* Fri Sep 15 2000 choeger@suse.de
- update to version 0.21
* Tue Aug 29 2000 cihlar@suse.cz
- splited to perl_ldp and p_ldaps
- removed p_iossl from neededforbuild
* Wed Aug 23 2000 cihlar@suse.cz
- added p_iossl to Requires and neededforbuild
* Wed Aug 23 2000 cihlar@suse.cz
- update to version 0.20
- added BuildRoot
- bzipped sources
* Fri Mar 24 2000 ug@suse.de
- new version 0.14 -> 0.15
* Thu Mar 23 2000 ug@suse.de
- added to distribution
